@@ -245,13 +245,30 @@ class FscGrades(CanvasConnection):
         enrollments = self.course.get_enrollments(
             type=['StudentEnrollment'], state=[self.student_status])
         canvas_grades = defaultdict(list)
+        overridden_grades = []
         for enrollment in enrollments:
             canvas_grades['Student Number'].append(enrollment.user['sis_user_id'])
             surname, preferred_name = enrollment.user['sortable_name'].split(', ')
             canvas_grades['Surname'].append(surname)
             canvas_grades['Preferred Name'].append(preferred_name)
-            canvas_grades['Percent Grade'].append(enrollment.grades['final_score'])
+            if 'override_score' in enrollment.grades:
+                overridden_grades.append(
+                    f"{preferred_name:<12} {surname:<12}"
+                    f" {enrollment.grades['final_score']:<4} ->"
+                    f" {enrollment.grades['override_score']}")
+                canvas_grades['Percent Grade'].append(enrollment.grades['override_score'])
+            else:
+                canvas_grades['Percent Grade'].append(enrollment.grades['final_score'])
+            if 'unposted_final_score' in enrollment.grades:
+                if enrollment.grades['unposted_final_score'] != enrollment.grades['final_score']:
+                    click.echo(
+                        'There are unposted assignments that would change the final score of '
+                        + f'{preferred_name} {surname}. Please post all assignments on Canvas.')
         self.canvas_grades = pd.DataFrame(canvas_grades)
+        if len(overridden_grades) > 0:
+            click.echo('Students with manual Canvas override of their final grade:')
+            [click.echo(grade) for grade in overridden_grades]
+            click.echo()
         return
 
     def drop_student_entries(self):
@@ -311,6 +328,8 @@ class FscGrades(CanvasConnection):
         self.fsc_grades = self.canvas_grades.copy()
         fsc_fields = ['Campus', 'Course', 'Section', 'Session', 'Subject',
                       'Standing', 'Standing Reason']
+        # Remove the session number which is only present on Canvas but not FSC
+        self.session = self.session[:-1]
         self.fsc_grades[fsc_fields] = (
             self.campus, self.course, self.section, self.session, self.subject, '', '')
         # Reorder columns to match the required FSC format
@@ -336,7 +355,7 @@ class FscGrades(CanvasConnection):
         """Create a histogram and interactive strip chart for the grade distribution"""
         hist = (
             alt.Chart(self.fsc_grades, height=200).mark_bar().encode(
-                alt.X('Percent Grade', bin=True, title='', axis=alt.Axis(labels=False)),
+                alt.X('Percent Grade', bin=alt.Bin(maxbins=15), title='', axis=alt.Axis(labels=False)),
                 alt.Y('count()', title='Number of students')))
         strip = (
             alt.Chart(self.fsc_grades, height=60)
